pub struct CanExecuteResponse(pub u32);Tuple Fields
0: u32Trait Implementations
Sourceimpl Clone for CanExecuteResponse
impl Clone for CanExecuteResponse
Sourcefn clone(&self) -> CanExecuteResponse
fn clone(&self) -> CanExecuteResponse
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CanExecuteResponse
impl Debug for CanExecuteResponse
Sourceimpl<'de> Deserialize<'de> for CanExecuteResponse
impl<'de> Deserialize<'de> for CanExecuteResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<CanExecuteFlag> for CanExecuteResponse
impl From<CanExecuteFlag> for CanExecuteResponse
Sourcefn from(flag: CanExecuteFlag) -> Self
fn from(flag: CanExecuteFlag) -> Self
Converts to this type from the input type.
Sourceimpl From<CanExecuteResponse> for CanExecuteFlag
impl From<CanExecuteResponse> for CanExecuteFlag
Sourcefn from(value: CanExecuteResponse) -> Self
fn from(value: CanExecuteResponse) -> Self
Converts to this type from the input type.
Sourceimpl JsonSchema for CanExecuteResponse
impl JsonSchema for CanExecuteResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for CanExecuteResponse
impl PartialEq for CanExecuteResponse
Sourceimpl Serialize for CanExecuteResponse
impl Serialize for CanExecuteResponse
impl StructuralPartialEq for CanExecuteResponse